@@ -35,8 +35,8 @@
 class SortProxyModel : public QSortFilterProxyModel
 {
     public:
-        SortProxyModel(QObject *parent = 0) : QSortFilterProxyModel(parent) {}
-        ~SortProxyModel() {}
+        explicit SortProxyModel(QObject *parent = nullptr) : QSortFilterProxyModel(parent) {}
+        ~SortProxyModel() Q_DECL_OVERRIDE {}
         inline const CursorTheme *theme(const QModelIndex &index) const;
         inline QModelIndex findIndex(const QString &name) const;
         inline QModelIndex defaultIndex() const;
